@@ -10,6 +10,7 @@ pub mod claim_receipt_mint;
 pub mod issue;
 pub mod unissue;
 pub mod claim;
+pub mod transfer;
 pub mod invalidate;
 pub mod create_mint_manager;
 pub mod close_mint_manager;
@@ -26,6 +27,7 @@ pub use claim_receipt_mint::*;
 pub use issue::*;
 pub use unissue::*;
 pub use claim::*;
+pub use transfer::*;
 pub use invalidate::*;
 pub use create_mint_manager::*;
 pub use close_mint_manager::*;
