@@ -76,16 +76,24 @@ pub const MINT_COUNTER_SIZE: usize = 8 + std::mem::size_of::<MintCounter>() + 8;
 #[account]
 pub struct MintCounter {
     pub bump: u8,
-    pub token_manager: Pubkey,
+    pub mint: Pubkey,
     pub count: u64,
 }
 
 pub const CLAIM_RECEIPT_SEED: &str = "claim-receipt";
 pub const CLAIM_RECEIPT_SIZE: usize = 8 + std::mem::size_of::<ClaimReceipt>() + 8; 
 #[account]
-pub struct ClaimReceipt {}
+pub struct ClaimReceipt {
+    pub mint_count: u64,
+    pub token_manager: Pubkey,
+    pub target: Pubkey
+}
 
 pub const TRANSFER_RECEIPT_SEED: &str = "transfer-receipt";
 pub const TRANSFER_RECEIPT_SIZE: usize = 8 + std::mem::size_of::<TranferReceipt>() + 8; 
 #[account]
-pub struct TranferReceipt {}
+pub struct TranferReceipt {
+    pub mint_count: u64,
+    pub token_manager: Pubkey,
+    pub target: Pubkey
+}
